# Yatte: a simple task runner

Make and Bash are useful tools but the syntax can be tricky, especially if you’re writing Bash inside a Makefile. And sometimes you need the flexibility and expressivity of a proper programming language with a standard library.

If you know Ruby, you’re probably already familiar with Rake; and for Python there’s Invoke. But maybe you don’t want to invest time in learning a new tool and its idiosyncracies.

Yatte is for when you just want to write a Python script and get back to work.

Note: A promising language-agnostic alternative is just.

The Quickstart describes how to use Yatte.

Latest version
  0.9.0 (2022-02-07)
License
  BSD 3-Clause
Project links
  Documentation
  Source code
  Mailing list